@@ -9,7 +9,7 @@ ebic.wr.bsreg <- function(target, dataset, wei = NULL, gam = NULL) {
     p <- dm[2]  ## number of variables
   }  
   if ( p > n ) {
-    res <- paste("The number of variables is hiher than the sample size. No backward procedure was attempted")
+    res <- paste("The number of variables is higher than the sample size. No backward procedure was attempted")
     
   } else {
     
@@ -23,7 +23,7 @@ ebic.wr.bsreg <- function(target, dataset, wei = NULL, gam = NULL) {
     tool <- numeric(p + 1)
     
     ini <- survival::survreg( target ~.,  data = dataset, weights = wei, dist = "weibull" )
-    bic0 <-  - 2 * logLik(ini) + (length(ini$coefficients) + 1) * logn    ## initial BIC  
+    bic0 <-  - 2 * logLik(ini) + (length(ini$coefficients) + 1) * logn    ## initial bic  
     tool[1] <- bic0
     bic <- numeric(p)
     M <- dim(dataset)[2] - 1
@@ -39,8 +39,8 @@ ebic.wr.bsreg <- function(target, dataset, wei = NULL, gam = NULL) {
         mat <- matrix(0, nrow = 0, ncol = 2 )
       }
       runtime <- proc.time() - tic
-      colnames(info) <- c("Variables", "BIC")
-      colnames(mat) <- c("Variables", "BIC")
+      colnames(info) <- c("Variables", "eBIC")
+      colnames(mat) <- c("Variables", "eBIC")
       res <- list(runtime = runtime, info = info, mat = mat )
       
     } else { 
@@ -53,8 +53,8 @@ ebic.wr.bsreg <- function(target, dataset, wei = NULL, gam = NULL) {
     mat <- cbind(1:p, bic )
     sel <- which.min( mat[, 2] )
     info <- matrix( 0, nrow = 1, ncol = 2 )
-    colnames(info) <- c("Variables", "BIC")
-    colnames(mat) <- c("Variables", "BIC")
+    colnames(info) <- c("Variables", "eBIC")
+    colnames(mat) <- c("Variables", "eBIC")
     
     if ( bic0 - mat[sel, 2] < 0  ) {
       runtime <- proc.time() - tic
