@@ -25,16 +25,10 @@ lm.fsreg_2.heavy <- function(target, dataset, iniset = NULL, threshold = 0.05, w
   }
   
   ## is there already an initial set of variables to start with?
-  if ( is.null(iniset) ) {
-    da <- 0
-    pa <- 0
-    
-  } else {
-    pa <- NCOL(iniset)
-    da <- 1:pa
-    dataset <- cbind(iniset, dataset)
-  }  
-  
+  pa <- NCOL(iniset)
+  da <- 1:pa
+  dataset <- cbind(iniset, dataset)
+
   n <- length(target)  ## sample size
   con <- log(n)
   tool <- numeric( length( min(n, p) ) )
@@ -50,14 +44,14 @@ lm.fsreg_2.heavy <- function(target, dataset, iniset = NULL, threshold = 0.05, w
      fit1rss <- fit1$RSS 
      d1 <- length( coef(fit1) )
      for (i in 1:pn) {
-       fit2 <- speedglm::speedlm( target ~., data = as.data.frame( dataset[, c(da, pa + i)] ), weights= wei )
+       fit2 <- speedglm::speedlm( target ~., data = dataset[, c(da, pa + i)], weights= wei )
        d2 <- length( coef(fit2) )
        df1 <- d2 - d1
        df2 <- n - d2
        stat[i] <- (fit1rss - fit2$RSS)/df1 / ( fit2$RSS /df2 )
        pval[i] <- pf( stat[i], df1, df2, lower.tail = FALSE, log.p = TRUE )
      } 	
-      mat <- cbind(1:p, pval, stat)
+     mat <- cbind(1:p, pval, stat)
     
   } else {
     cl <- makePSOCKcluster(ncores)
@@ -65,38 +59,35 @@ lm.fsreg_2.heavy <- function(target, dataset, iniset = NULL, threshold = 0.05, w
     fit1 <- speedglm::speedlm( target ~., data = as.data.frame(iniset), weights = wei )
     fit1rss <- fit1$RSS 
     d1 <- length( coef(fit1) )
-    mat <- matrix(0, p, 2)
     mod <- foreach( i = 1:p, .combine = rbind, .export = "speedlm", .packages = "speedglm" ) %dopar% {
-      fit2 <- speedlm( target ~., data = as.data.frame( dataset[, c(da, pa + i)] ), weights = wei )
+      fit2 <- speedlm( target ~., data = dataset[, c(da, pa + i)], weights = wei )
       d2 <- length( coef(fit2) )
       df1 <- d2 - d1
       df2 <- n - d2
-      stat[i] <- (fit1rss - fit2$RSS)/df1 / ( fit2$RSS /df2 )
-      pval[i] <- pf( stat[i], df1, df2, lower.tail = FALSE, log.p = TRUE )
-      mat[i, ] <- c(pval[i], stat[i]) 
+      stat <- (fit1rss - fit2$RSS)/df1 / ( fit2$RSS /df2 )
+      pval <- pf( stat, df1, df2, lower.tail = FALSE, log.p = TRUE )
+      return( c(pval, stat) )
     }
     stopCluster(cl)	 	  
-    
     mat <- cbind(1:p, mod)      
   }
   
   colnames(mat) <- c( "variables", "log.p-value", "stat" )
   rownames(mat) <- 1:p
   sel <- which.min(mat[, 2])
-  sela <- sel
+  sela <- pa + sel
   
   if ( mat[sel, 2] < threshold ) {
     
     info[k, ] <- mat[sel, ]
-    mat <- mat[-sel, ] 
-    if ( !is.matrix(mat) )   mat <- matrix(mat, ncol = 3) 
+    mat <- mat[-sel, , drop = FALSE] 
     
     if ( stopping == "adjrsq" ) {
-       mi = speedglm::speedlm( target ~., data = as.data.frame( dataset[, c(da, sel) ] ), weights = wei )
+       mi = speedglm::speedlm( target ~., data = dataset[, c(da, sel) ], weights = wei )
        tool[k] <- as.numeric( summary( mi )[[ 11 ]] )
 
     } else if ( stopping  == "BIC" ) { 
-        mi = speedglm::speedlm( target ~., data = as.data.frame( dataset[, c(da, sel) ] ), weights = wei )
+        mi = speedglm::speedlm( target ~., data = dataset[, c(da, sel) ], weights = wei )
         tool[k] <-  - 2 * logLik(mi) + length( coef(mi) ) * con 
     }
     moda[[ k ]] <- mi
@@ -113,7 +104,7 @@ lm.fsreg_2.heavy <- function(target, dataset, iniset = NULL, threshold = 0.05, w
        fit1rss <- mi$RSS 
        d1 <- length( coef(fit1) )
        for (i in 1:pn) {
-          fit2 = speedglm::speedlm( target ~., data = as.data.frame( dataset[, c(da, sel, mat[pa + i, 1]) ] ), weights= wei )
+          fit2 = speedglm::speedlm( target ~., data = dataset[, c(da, sel, pa + mat[i, 1]) ], weights= wei )
           d2 = length( coef(fit2) )
           df1 = d2 - d1
           df2 = n - d2
@@ -128,13 +119,13 @@ lm.fsreg_2.heavy <- function(target, dataset, iniset = NULL, threshold = 0.05, w
       stat <- pval <- numeric(pn) 
       mata <- matrix(0, pn, 2)
       mod <- foreach( i = 1:pn, .combine = rbind, .export = "speedlm", .packages = "speedglm") %dopar% {
-        fit2 <- speedlm( target ~., data = as.data.frame( dataset[, c(da, sel, mat[pa + i, 1]) ] ), weights = wei )
+        fit2 <- speedlm( target ~., data = dataset[, c(da, sel, pa + mat[pa + i, 1]) ], weights = wei )
         d2 <- length( coef(fit2) )
         df1 <- d2 - d1
         df2 <- n - d2
-        stat[i] <- (fit1rss - fit2$RSS)/df1 / ( fit2$RSS /df2 )
-        pval[i] <- pf( mat[i, 3], df1, df2, lower.tail = FALSE, log.p = TRUE )
-        mata[i, ] <- c( pval[i], stat[i] ) 
+        stat <- (fit1rss - fit2$RSS)/df1 / ( fit2$RSS /df2 )
+        pval <- pf( stat, df1, df2, lower.tail = FALSE, log.p = TRUE )
+        return( c( pval, stat ) )
       }
       stopCluster(cl)
       mat <- cbind(mat[, 1], mod)   
@@ -143,12 +134,12 @@ lm.fsreg_2.heavy <- function(target, dataset, iniset = NULL, threshold = 0.05, w
   }
   
   ina <- which.min(mat[, 2])
-  sel <- mat[ina, 1]     
+  sel <- pa + mat[ina, 1]     
   
   if ( stopping == "adjrsq" ) {
     
     if ( mat[ina, 2] < threshold ) {
-        ma <- speedglm::speedlm( target ~., data=as.data.frame( dataset[, c(da, sela, sel) ] ), weights = wei, y = FALSE, model = FALSE )
+        ma <- speedglm::speedlm( target ~., data = dataset[, c(da, sela, sel) ], weights = wei, y = FALSE, model = FALSE )
         tool[k] <- as.numeric( summary( ma )[[ 11 ]] )		
 
       if ( tool[ k ] - tool[ k - 1 ] <= tol ) {
@@ -166,7 +157,7 @@ lm.fsreg_2.heavy <- function(target, dataset, iniset = NULL, threshold = 0.05, w
   } else if ( stopping == "BIC" ) {
     
     if ( mat[ina, 2] < threshold ) {
-        ma <- speedglm::speedlm( target ~., data = as.data.frame( dataset[, c(da, sela, sel) ] ), weights = wei )
+        ma <- speedglm::speedlm( target ~., data = dataset[, c(da, sela, sel) ], weights = wei )
         tool[k] <-  - 2 * logLik(ma) + length( coef(ma ) ) * con
 
       if ( tool[ k - 1] - tool[ k ] <= tol ) {
@@ -174,7 +165,7 @@ lm.fsreg_2.heavy <- function(target, dataset, iniset = NULL, threshold = 0.05, w
         
       } else {  
         info <- rbind(info, mat[ina, ] )
-        sela <- info[, 1]
+        sela <- c(sela, sel)
         mat <- mat[-ina, , drop = FALSE]
         moda[[ k ]] <- ma
       }
@@ -195,7 +186,7 @@ lm.fsreg_2.heavy <- function(target, dataset, iniset = NULL, threshold = 0.05, w
          fit1rss <- ma$RSS 
          d1 <- length( coef(fit1) )
          for (i in 1:pn) {
-            fit2 = speedglm::speedlm( target ~., data = as.data.frame( dataset[, c(da, sel, mat[pa + i, 1]) ] ), weights= wei )
+            fit2 = speedglm::speedlm( target ~., data = dataset[, c(da, sel, pa + mat[pa + i, 1]) ], weights= wei )
             d2 = length( coef(fit2) )
             df1 = d2 - d1
             df2 = n - d2
@@ -206,28 +197,26 @@ lm.fsreg_2.heavy <- function(target, dataset, iniset = NULL, threshold = 0.05, w
         cl <- makePSOCKcluster(ncores)
         registerDoParallel(cl)
         fit1rss <- ma$RSS 
-        stat <- pval <- numeric(pn) 
-        mata <- matrix(0, pn, 2)
         mod <- foreach( i = 1:pn, .combine = rbind, .export = "speedlm", .packages = "speedglm") %dopar% {
-          fit2 <- speedlm( target ~., data = as.data.frame( dataset[, c(da, sela, mat[pa + i, 1]) ] ), weights = wei )
+          fit2 <- speedlm( target ~., data = dataset[, c(da, sela, pa + mat[i, 1]) ], weights = wei )
           d2 = length( coef(fit2) )
           df1 = d2 - d1
           df2 = n - d2
-          stat[i] = (fit1rss - fit2$RSS)/df1 / ( fit2$RSS /df2 )
-          pval[i] = pf( mat[i, 3], df1, df2, lower.tail = FALSE, log.p = TRUE )
-          mata[i, ] <- c( pval[i], stat[i] ) 
+          stat = (fit1rss - fit2$RSS)/df1 / ( fit2$RSS /df2 )
+          pval = pf( stat, df1, df2, lower.tail = FALSE, log.p = TRUE )
+          return( c( pval, stat ) )
         }
         stopCluster(cl)
         mat <- cbind( mat[, 1], mod )   
       }
       
       ina <- which.min(mat[, 2])
-      sel <- mat[ina, 1]   
+      sel <- pa + mat[ina, 1]   
       
       if ( stopping == "BIC" ) {
         
         if ( mat[ina, 2] < threshold ) {
-          ma <- speedglm::speedlm( target ~., data = as.data.frame( dataset[, c(da, sela, sel)] ), weights = wei )
+          ma <- speedglm::speedlm( target ~., data = dataset[, c(da, sela, sel)], weights = wei )
           tool[k] <-  - 2 * logLik(ma) + length( coef(ma ) ) * con		
           if ( tool[ k - 1] - tool[ k ] <= tol ) {
             info <- rbind(info, c( 1e300, 0, 0 ) )
@@ -244,13 +233,13 @@ lm.fsreg_2.heavy <- function(target, dataset, iniset = NULL, threshold = 0.05, w
         
       } else if ( stopping == "adjrsq" ) {
         if ( mat[ina, 2] < threshold ) {
-          ma <- speedglm::speedlm( target ~., data=as.data.frame( dataset[, c(da, sela, sel) ] ), weights = wei )
+          ma <- speedglm::speedlm( target ~., data = dataset[, c(da, sela, sel) ], weights = wei )
           tool[k] <- as.numeric( summary( ma )[[ 11 ]] )	
           if ( tool[ k ] - tool[ k - 1 ] <= tol ) {
             info <- rbind(info, c( 1e300, 0, 0 ) )
           } else { 
             info <- rbind( info, mat[ina, ] )
-            sela <- info[, 1]
+            sela <- c(sela, sel)
             mat <- mat[-ina, , drop = FALSE]
             moda[[ k ]] <- ma
           }
@@ -268,7 +257,7 @@ lm.fsreg_2.heavy <- function(target, dataset, iniset = NULL, threshold = 0.05, w
   if (d == 0) {
     final <- speedglm::speedlm( target ~., data = as.data.frame( iniset ), weights = wei )
   } else {
-    final <- speedglm::speedlm( target ~., data = as.data.frame( dataset[, c(da, sela) ] ), weights = wei )
+    final <- speedglm::speedlm( target ~., data = dataset[, c(da, sela) ], weights = wei )
     info <- info[1:d, , drop = FALSE]
     info <- cbind( info, tool[ 1:d ] ) 
     colnames(info) <- c( "variables", "log.p-value", "stat", stopping )
